@@ -1,10 +1,11 @@
 use Log::Log4perl qw(:easy);
-use Log::Log4perl::CommandLine;
+use Log::Log4perl::CommandLine qw(:all);
 
 use SampleModule;
 
 SampleModule::test();
 
+TRACE "trace message";
 DEBUG "debug message";
 INFO  "info  message";
 WARN  "warn  message";
