@@ -1,6 +1,8 @@
 use Log::Log4perl qw(:easy);
-use Log::Log4perl::CommandLine { level => $INFO };
+use Log::Log4perl::CommandLine ':all',
+                               ':loginit' => { level => $INFO };
 
+TRACE "trace message";
 DEBUG "debug message";
 INFO  "info  message";
 WARN  "warn  message";
