@@ -1,6 +1,8 @@
 use Log::Log4perl qw(:easy);
-use Log::Log4perl::CommandLine { layout => '%c %m%n' };
+use Log::Log4perl::CommandLine ':all',
+                               ':loginit' => { layout => '%c %m%n' };
 
+TRACE "trace message";
 DEBUG "debug message";
 INFO  "info  message";
 WARN  "warn  message";
