@@ -1,5 +1,6 @@
 use Log::Log4perl qw(:easy);
-use Log::Log4perl::CommandLine \q(
+use Log::Log4perl::CommandLine ':all',
+':loginit' => q(
     log4perl.logger = WARN,  screen
     log4perl.appender.screen=Log::Log4perl::Appender::Screen
     log4perl.appender.screen.layout=Log::Log4perl::Layout::PatternLayout
@@ -10,6 +11,7 @@ use SampleModule;
 
 SampleModule::test();
 
+TRACE "trace message";
 DEBUG "debug message";
 INFO  "info  message";
 WARN  "warn  message";
